import { FromEnvInit } from "@aws-sdk/credential-provider-env";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromEnv: (
  init?: FromEnvInit
) => AwsCredentialIdentityProvider;
