import { CredentialProviderOptions } from "@aws-sdk/types";
import { RemoteProviderConfig as _RemoteProviderInit } from "@smithy/credential-provider-imds";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromInstanceMetadata: (
  init?: _RemoteProviderInit & CredentialProviderOptions
) => AwsCredentialIdentityProvider;
