import { type FromLoginCredentialsInit } from "@aws-sdk/credential-provider-login";
import type { RuntimeConfigAwsCredentialIdentityProvider } from "@aws-sdk/types";
/**
 * Creates a credential provider that sources credentials from `aws login` cached tokens
 * @public
 */
export declare const fromLoginCredentials: (init?: FromLoginCredentialsInit) => RuntimeConfigAwsCredentialIdentityProvider;
