import { FromLoginCredentialsInit } from "@aws-sdk/credential-provider-login";
import { RuntimeConfigAwsCredentialIdentityProvider } from "@aws-sdk/types";
export declare const fromLoginCredentials: (
  init?: FromLoginCredentialsInit
) => RuntimeConfigAwsCredentialIdentityProvider;
