import { DefaultProviderInit } from "@aws-sdk/credential-provider-node";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromNodeProviderChain: (
  init?: DefaultProviderInit
) => AwsCredentialIdentityProvider;
