import { FromWebTokenInit } from "@aws-sdk/credential-provider-web-identity";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromWebToken: (
  init: FromWebTokenInit
) => AwsCredentialIdentityProvider;
